@@ -4,12 +4,21 @@ use oxiri::Iri;
 use std::str;
 
 fuzz_target!(|data: &[u8]| {
-    let Ok(s) = str::from_utf8(data) else {
+    let parts = data.split(|c| *c == b'\0').collect::<Vec<_>>();
+    let Ok([relative, base]) = <[&[u8]; 2]>::try_from(parts) else {
         return;
     };
-    let base = Iri::parse("http://a/b/c/d;p?q").unwrap();
-    let unchecked = base.resolve_unchecked(s);
-    let Ok(valid) = base.resolve(s) else {
+    let Ok(relative) = str::from_utf8(relative) else {
+        return;
+    };
+    let Ok(base) = str::from_utf8(base) else {
+        return;
+    };
+    let Ok(base) = Iri::parse(base) else {
+        return;
+    };
+    let unchecked = base.resolve_unchecked(relative);
+    let Ok(valid) = base.resolve(relative) else {
         return;
     };
     // We check that unchecked resolving gives the same result
